@@ -22,8 +22,6 @@
 #ifndef MIXER_PULSE_H
 #define MIXER_PULSE_H
 
-#include <QString>
-
 #include "mixer_backend.h"
 #include <pulse/pulseaudio.h>
 
@@ -66,6 +64,8 @@ class Mixer_PULSE : public Mixer_Backend
 
         bool needsPolling() override { return false; }
 
+        // Only used internally, but need to be able to be called by
+        // static PulseAudio callback functions.
         void triggerUpdate();
         void addWidget(int index, bool = false);
         void removeWidget(int index);
